==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/gl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Breve descrición da regra",
    "Add rule" : "Engadir unha regra",
    "Reset" : "Restabelecer",
    "Save" : "Gardar",
    "Saving…" : "Gardando…",
    "Group list is empty" : "A lista de grupos está baleira",
    "Unable to retrieve the group list" : "Non é posíbel recuperar a lista de grupos",
    "Saved" : "Gardado",
    "Saving failed:" : "Produciuse unha falla ao gardar:",
    "Add rule group" : "Engadir unha regra de grupo",
    "File MIME type" : "Tipo MIME do ficheiro",
    "is" : "é",
    "is not" : "non é",
    "matches" : "coincidencias",
    "does not match" : "non coinciden",
    "Example: {placeholder}" : "Exemplo: {placeholder}",
    "File name" : "Nome de ficheiro",
    "File size (upload)" : "Tamaño do ficheiro (envío)",
    "less" : "menor",
    "less or equals" : "menor ou igual",
    "greater or equals" : "maior ou igual",
    "greater" : "maior",
    "File system tag" : "Etiqueta do sistema de ficheiros",
    "is tagged with" : "está etiquetado con",
    "is not tagged with" : "non está etiquetado con",
    "Select tag…" : "Seleccionar a etiqueta…",
    "Request remote address" : "Solicitar o enderezo remoto",
    "matches IPv4" : "coincidencias IPv4",
    "does not match IPv4" : "sen coincidencias IPv4",
    "matches IPv6" : "coincidencias IPv6",
    "does not match IPv6" : "sen coincidencias IPv6",
    "Request time" : "Tempo da solicitude",
    "between" : "entre",
    "not between" : "non entre",
    "Start" : "Inicio",
    "End" : "Final",
    "Select timezone…" : "Seleccionar o fuso horario…",
    "Request URL" : "Solicitar URL",
    "Predefined URLs" : "URL predefinidos",
    "Files WebDAV" : "Ficheiros WebDAV",
    "Request user agent" : "Solicitar axente de usuario",
    "Sync clients" : "Sincronizar clientes",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de escritorio",
    "Thunderbird & Outlook addons" : "Complementos do Thunderbird e do Outlook",
    "User group membership" : "Pertencia a un grupo de usuarios",
    "is member of" : "é participante en",
    "is not member of" : "non é participante en",
    "The given operator is invalid" : "O operador indicado é incorrecto",
    "The given regular expression is invalid" : "A expresión regular indicada é incorrecta",
    "The given file size is invalid" : "O tamaño do ficheiro indicado é incorrecto",
    "The given tag id is invalid" : "A etiqueta indicada é incorrecta",
    "The given IP range is invalid" : "O intervalo de IP indicado é incorrecto",
    "The given IP range is not valid for IPv4" : "O intervalo de IP indicado é incorrecto para IPv4",
    "The given IP range is not valid for IPv6" : "O intervalo de IP indicado é incorrecto para IPv6",
    "The given time span is invalid" : "O intervalo temporal indicado é incorrecto",
    "The given start time is invalid" : "A hora de inicio indicada é incorrecta",
    "The given end time is invalid" : "A hora final indicada é incorrecta",
    "The given group does not exist" : "O grupo indicado non existe",
    "Check %s is invalid or does not exist" : "A proba %s é incorrecta ou non existe",
    "Operation #%s does not exist" : "Non existe a operación num. %s ",
    "Operation %s does not exist" : "Non existe a operación %s",
    "Operation %s is invalid" : "A operación %s é incorrecta",
    "Check %s does not exist" : "Non existe a proba %s",
    "Check %s is invalid" : "A proba %s é incorrecta",
    "Check #%s does not exist" : "Non existe a proba num. %s ",
    "Workflow" : "Fluxo de traballo",
    "Files workflow engine" : "Motor de fluxo de traballo de ficheiros",
    "Open documentation" : "Documentación aberta",
    "Loading…" : "Cargando…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/gl.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Breve descrición da regra",
    "Add rule" : "Engadir unha regra",
    "Reset" : "Restabelecer",
    "Save" : "Gardar",
    "Saving…" : "Gardando…",
    "Group list is empty" : "A lista de grupos está baleira",
    "Unable to retrieve the group list" : "Non é posíbel recuperar a lista de grupos",
    "Saved" : "Gardado",
    "Saving failed:" : "Produciuse un fallo ao gardar:",
    "Add rule group" : "Engadir unha regra de grupo",
    "File MIME type" : "Tipo MIME do ficheiro",
    "is" : "é",
    "is not" : "non é",
    "matches" : "coincidencias",
    "does not match" : "non coinciden",
    "Example: {placeholder}" : "Exemplo: {placeholder}",
    "File name" : "Nome de ficheiro",
    "File size (upload)" : "Tamaño do ficheiro (envío)",
    "less" : "menor",
    "less or equals" : "menor ou igual",
    "greater or equals" : "maior ou igual",
    "greater" : "maior",
    "File system tag" : "Etiqueta do sistema de ficheiros",
    "is tagged with" : "está etiquetado con",
    "is not tagged with" : "non está etiquetado con",
    "Select tag…" : "Seleccionar a etiqueta…",
    "Request remote address" : "Solicitar o enderezo remoto",
    "matches IPv4" : "coincidencias IPv4",
    "does not match IPv4" : "sen coincidencias IPv4",
    "matches IPv6" : "coincidencias IPv6",
    "does not match IPv6" : "sen coincidencias IPv6",
    "Request time" : "Tempo da solicitude",
    "between" : "entre",
    "not between" : "non entre",
    "Start" : "Inicio",
    "End" : "Final",
    "Select timezone…" : "Seleccionar o fuso horario…",
    "Request URL" : "Solicitar URL",
    "Predefined URLs" : "URL predefinidos",
    "Files WebDAV" : "Ficheiros WebDAV",
    "Request user agent" : "Solicitar axente de usuario",
    "Sync clients" : "Sincronizar clientes",
    "Android client" : "Cliente Android",
    "iOS client" : "Cliente iOS",
    "Desktop client" : "Cliente de escritorio",
    "Thunderbird & Outlook addons" : "Complementos do Thunderbird e do Outlook",
    "User group membership" : "Pertencia a un grupo de usuarios",
    "is member of" : "é membro de",
    "is not member of" : "non é membro de",
    "The given operator is invalid" : "O operador indicado é incorrecto",
    "The given regular expression is invalid" : "A expresión regular indicada é incorrecta",
    "The given file size is invalid" : "O tamaño do ficheiro indicado é incorrecto",
    "The given tag id is invalid" : "A etiqueta indicada é incorrecta",
    "The given IP range is invalid" : "O intervalo de IP indicado é incorrecto",
    "The given IP range is not valid for IPv4" : "O intervalo de IP indicado é incorrecto para IPv4",
    "The given IP range is not valid for IPv6" : "O intervalo de IP indicado é incorrecto para IPv6",
    "The given time span is invalid" : "O intervalo temporal indicado é incorrecto",
    "The given start time is invalid" : "A hora de inicio indicada é incorrecta",
    "The given end time is invalid" : "A hora final indicada é incorrecta",
    "The given group does not exist" : "O grupo indicado non existe",
    "Check %s is invalid or does not exist" : "A proba %s é incorrecta ou non existe",
    "Operation #%s does not exist" : "Non existe a operación num. %s ",
    "Operation %s does not exist" : "Non existe a operación %s",
    "Operation %s is invalid" : "A operación %s é incorrecta",
    "Check %s does not exist" : "Non existe a proba %s",
    "Check %s is invalid" : "A proba %s é incorrecta",
    "Check #%s does not exist" : "Non existe a proba num. %s ",
    "Workflow" : "Fluxo de traballo",
    "Files workflow engine" : "Motor de fluxo de traballo de ficheiros",
    "Open documentation" : "Documentación aberta",
    "Loading…" : "Cargando…"
},
"nplurals=2; plural=(n != 1);");
